@@ -76,7 +76,7 @@ async def get_AccountInfo(qqid,info):
                 else:
                     return '服务器参数似乎输错了呢'
             elif params:
-                print(params)
+                print('下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦')
             else:
                 return '您似乎准备用游戏昵称查询水表，请检查参数中时候包含服务器和游戏昵称，以空格区分'
         else:
@@ -85,7 +85,6 @@ async def get_AccountInfo(qqid,info):
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=10)
             result = resp.json()
-        print(result)
         if result['code'] == 200 and result['data']:
             template = env.get_template("wws-info.html")
             template_data = await set_infoparams(result['data'])
